@@ -121,10 +121,12 @@ class UefiExtractor:
 
         return True
 
-    def extract_all(self) -> None:
+    def extract_all(self, ignore_guid: bool = False) -> None:
         self._extract()
         for guid in self._info:
-            if self._info[guid]["content"] is not None and guid in self._file_guids:
+            if ignore_guid or (
+                self._info[guid]["content"] is not None and (guid in self._file_guids)
+            ):
                 self.binaries.append(
                     UefiBinary(
                         content=self._info[guid]["content"],
