@@ -423,6 +423,15 @@ class UefiRule:
         except KeyError:
             return None
 
+    @property
+    def target(self) -> Optional[str]:
+        """Get optional rule target from the metadata block"""
+
+        try:
+            return self._uefi_rule["meta"]["target"]
+        except KeyError:
+            return None
+
     def _get_variants(self) -> Dict[str, UefiRuleVariant]:
         """Get rules variants"""
 
@@ -800,11 +809,10 @@ class UefiScanner:
         return final_res
 
     def _search_guid(self, guid_rule: UefiGuid) -> bool:
-        for protocol_analyzer in self._uefi_analyzer.protocols:
-            if (
-                guid_rule.name == protocol_analyzer.name
-                and guid_rule.value == protocol_analyzer.value
-            ):
+        for guid in self._uefi_analyzer.protocol_guids:
+            if guid_rule.name == guid.name or guid_rule.value == guid.value:
+                # True if name or value is matches
+                # so that UNKNOWN_GUIDs can be specified
                 return True
         return False
 
@@ -1051,7 +1059,13 @@ class UefiScanner:
 
         return final_res
 
-    def _get_results_variants(self, rule_variant: UefiRuleVariant) -> bool:
+    def _get_results_variants(
+        self, rule_variant: UefiRuleVariant, target: Optional[str]
+    ) -> bool:
+        if target in ["firmware"]:
+            # match hex strings
+            return self._hex_strings_scanner(rule_variant.hex_strings)
+
         res = True
 
         # compare NVRAM variables
@@ -1101,7 +1115,9 @@ class UefiScanner:
 
         for uefi_rule in self._uefi_rules:
             for variant in uefi_rule.variants:
-                res = self._get_results_variants(uefi_rule.variants[variant])
+                res = self._get_results_variants(
+                    uefi_rule.variants[variant], uefi_rule.target
+                )
                 results.append(
                     UefiScannerRes(rule=uefi_rule, variant_label=variant, res=res)
                 )
